@@ -1,6 +1,4 @@
 package Weed::Components::Core::ChildNode;
-use strict;
-use warnings;
 
 use Weed '
 X3DChildNode : X3DNode { 
