@@ -1,6 +1,13 @@
 package Weed::Components::Core::Node;
-use strict;
-use warnings;
+
+sub setDescription {
+	my ( $this, $description ) = @_;
+
+	printf "%s %s\n", $this, $_
+	  foreach @{$description->{body}};
+
+	#die;
+}
 
 use Weed '
 X3DNode {
@@ -8,14 +15,9 @@ X3DNode {
 }
 ';
 
-sub setDescription {
-	my ( $this, $description ) = @_;
-	
-	#die;
-}
-
 sub create {
 	my ( $this, $name ) = @_;
+	#printf "%s->%s %s\n", $_[0]->getType, $_[0]->Weed::Package::sub, $_[0];
 	$this->setName($name);
 }
 
@@ -24,21 +26,22 @@ sub getTypeName { $_[0]->getType }
 sub setName { $_[0]->{name} = $_[1] || '' }
 sub getName { $_[0]->{name} }
 
-sub getFieldDefinitions { ${ $_[0]->SCALAR("FieldDefinitions") } }
+sub getFieldDefinitions { ${ $_[0]->Weed::Package::scalar("FieldDefinitions") } }
 
 1;
 __END__
+
 sub setFieldDescriptions {
 	my ( $this, $fieldDescriptions ) = @_;
 
-	${ $this->SCALAR("FieldDescriptions") } = $fieldDescriptions;
+	${ $this->Weed::Package::scalar("FieldDescriptions") } = $fieldDescriptions;
 	$this->setFieldDefinitions( [ map { new X3DFieldDefinition(@$_) } @$fieldDescriptions ] );
 }
 
 sub private::getFieldDescriptions {
 	my ($this) = @_;
-	my $fieldDescriptions = ${ $this->SCALAR("FieldDescriptions") };
-	$fieldDescriptions = $this->SUPER->private::getFieldDescriptions
+	my $fieldDescriptions = ${ $this->Weed::Package::scalar("FieldDescriptions") };
+	$fieldDescriptions = $this->SU PER->private::getFieldDescriptions
 	  unless ref $fieldDescriptions;
 	return $fieldDescriptions;
 }
@@ -47,7 +50,7 @@ sub getFieldDescriptions { $_[0]->private::getFieldDescriptions }
 
 sub setFieldDefinitions {
 	my ( $this, $fieldDefinitions ) = @_;
-	${ $this->SCALAR("FieldDefinitions") } = $fieldDefinitions;
+	${ $this->Weed::Package::scalar("FieldDefinitions") } = $fieldDefinitions;
 }
 sub toString {
 	printf "### %d\n", scalar @_;
